import base64
import json

import yaml


def get_secrets_from_json_file(file_path: str) -> dict:
    """
    Extract secrets from the given JSON file
    """
    try:
        with open(file_path, "r", encoding="utf-8") as fp:
            data = json.load(fp)
        output = {}
        for key, value in data["data"].items():
            output[key] = base64.b64decode(value).decode("utf-8")
        return output
    except FileNotFoundError as e:
        print(f"File not found '{file_path}' - {e}")
    except Exception as e:
        print(f"Invalid input file '{file_path}' - {e}")


def get_secrets_from_yaml_file(file_path: str) -> dict:
    """
    Extract secrets from the given YAML file
    """
    try:
        with open(file_path, "r", encoding="utf-8") as fp:
            data = yaml.safe_load(fp)
        output = {}
        for key, value in data["data"].items():
            output[key] = base64.b64decode(value).decode("utf-8")
        return output
    except FileNotFoundError as e:
        print(f"File not found '{file_path}' - {e}")
    except Exception as e:
        print(f"Invalid input file '{file_path}' - {e}")


if __name__ == "__main__":
    # opt = get_secrets_from_json_file("my-secret.json")
    opt = get_secrets_from_yaml_file("my-secret.yaml")
    print(opt)



import base64

from kubernetes import client, config


def get_kubernetes_secret(namespace: str, secret_name: str, kube_config: str) -> dict:
    """
    Retrieve the secret from Kubernetes using the K8 APIs
    Returns the decoded values of key value payers of the given secret
    """
    try:
        config.load_kube_config(config_file=kube_config)
    except Exception as e:
        print(f"Kube config file not found in '{kube_config}' - {e}")
        return
    v1 = client.CoreV1Api()
    output = {}

    try:
        secret = v1.read_namespaced_secret(secret_name, namespace)
        for key, value in secret.data.items():
            output[key] = base64.b64decode(value).decode("utf-8")
        return output
    except client.ApiException as e:
        if e.status == 404:
            print(f"Secret '{secret_name}' not found in the namespace '{namespace}'")
        else:
            print(f"Error occurred: {e}")


if __name__ == "__main__":
    get_kubernetes_secret("default", "my-secret", "~/.kube/config")



import click

from .secret_from_file import get_secrets_from_json_file, get_secrets_from_yaml_file
from .secret_from_kubernetes import get_kubernetes_secret


@click.command()
@click.option(
    "--namespace",
    default="default",
    help="Kubernetes namespace where your secret resides, default namespace is 'default'",
)
@click.option("--secret-name", help="Kubernetes secret name")
@click.option("--file", help="File which contain the Kubernetes secret, supports JSON or YAML files")
@click.option("--output-file", default="env", help="Output file for .env format, default name is env")
@click.option(
    "--kube-config",
    default="~/.kube/config",
    help="Location of the kube config file, by default it will take ~/.kube/config",
)
def convert(namespace, secret_name, file, output_file, kube_config):
    """
    Convert Kubernetes secret file to .env file with secrets as key value pairs
    Output: env file on a specified location, can override the env file name.
    """
    output = dict()
    if file:
        if file.lower().endswith(".json"):
            output = get_secrets_from_json_file(file)
        elif file.lower().endswith(".yml") or file.lower().endswith(".yaml"):
            output = get_secrets_from_yaml_file(file)
        else:
            print("Invalid file type, supports .yaml, .yml or .json")
    elif namespace and secret_name:
        output = get_kubernetes_secret(namespace=namespace, secret_name=secret_name, kube_config=kube_config)
    else:
        print(
            "You should provide secret name and namespace or the file name which contains the secret to generate the env file"
        )
    if output:
        with open(output_file, "w", encoding="utf-8") as fp:
            for key, value in output.items():
                fp.write(f"{key}={value}\n")
        print(f"Output env file generated at {output_file}")
